@@ -7,12 +7,13 @@ from optparse import OptionParser
 # the next line can be removed after installation
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
-import pyverilog.utils.version
+import pyverilog
 from pyverilog.vparser.preprocessor import preprocess
 
+
 def main():
     INFO = "Verilog Preprocessor"
-    VERSION = pyverilog.utils.version.VERSION
+    VERSION = pyverilog.__version__
     USAGE = "Usage: python example_preprocessor.py file ..."
 
     def showVersion():
@@ -22,12 +23,12 @@ def main():
         sys.exit()
 
     optparser = OptionParser()
-    optparser.add_option("-v","--version",action="store_true",dest="showversion",
-                         default=False,help="Show the version")
-    optparser.add_option("-I","--include",dest="include",action="append",
-                         default=[],help="Include path")
-    optparser.add_option("-D",dest="define",action="append",
-                         default=[],help="Macro Definition")
+    optparser.add_option("-v", "--version", action="store_true", dest="showversion",
+                         default=False, help="Show the version")
+    optparser.add_option("-I", "--include", dest="include", action="append",
+                         default=[], help="Include path")
+    optparser.add_option("-D", dest="define", action="append",
+                         default=[], help="Macro Definition")
     (options, args) = optparser.parse_args()
 
     filelist = args
@@ -35,14 +36,16 @@ def main():
         showVersion()
 
     for f in filelist:
-        if not os.path.exists(f): raise IOError("file not found: " + f)
+        if not os.path.exists(f):
+            raise IOError("file not found: " + f)
 
     if len(filelist) == 0:
         showVersion()
-        
+
     text = preprocess(filelist, include=options.include, define=options.define)
-    
+
     print(text)
 
+
 if __name__ == '__main__':
     main()
